==> haskell-parallel-3.2.2.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parallel
version: 3.2.2.0
id: parallel-3.2.2.0-BGtJixj8tYyBHs92byBvWM
key: parallel-3.2.2.0-BGtJixj8tYyBHs92byBvWM
license: BSD-3-Clause
maintainer: libraries@haskell.org
synopsis: Parallel programming library
description:
    This package provides a library for parallel programming.
    .
    For documentation start from the "Control.Parallel.Strategies"
    module below.
    .
    For more tutorial documentation, see the book <http://simonmar.github.io/pages/pcph.html Parallel and Concurrent Programming in Haskell>.
    .
    To understand the principles behind the library, see
    <http://simonmar.github.io/bib/papers/strategies.pdf Seq no more: Better Strategies for Parallel Haskell>.
category: Control, Parallelism
abi: c7dd7cab9f8cf16910b7e84be6ad13b5
exposed: True
exposed-modules:
    Control.Parallel Control.Parallel.Strategies Control.Seq
import-dirs: /usr/lib/ghc-8.6.1/site-local/parallel-3.2.2.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/parallel-3.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/parallel-3.2.2.0
hs-libraries: HSparallel-3.2.2.0-BGtJixj8tYyBHs92byBvWM
depends:
    array-0.5.2.0 base-4.12.0.0 containers-0.6.0.1 deepseq-1.4.4.0
    ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-parallel/html/parallel.haddock
haddock-html: /usr/share/doc/haskell-parallel/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parallel-3.2.2.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parallel
version: 3.2.2.0
id: parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ
key: parallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ
license: BSD-3-Clause
maintainer: libraries@haskell.org
synopsis: Parallel programming library
description:
    This package provides a library for parallel programming.
    .
    For documentation start from the "Control.Parallel.Strategies"
    module below.
    .
    For more tutorial documentation, see the book <http://simonmar.github.io/pages/pcph.html Parallel and Concurrent Programming in Haskell>.
    .
    To understand the principles behind the library, see
    <http://simonmar.github.io/bib/papers/strategies.pdf Seq no more: Better Strategies for Parallel Haskell>.
category: Control, Parallelism
abi: 9589315782f60f737b3ae75f9970a3cc
exposed: True
exposed-modules:
    Control.Parallel Control.Parallel.Strategies Control.Seq
import-dirs: /usr/lib/ghc-8.6.2/site-local/parallel-3.2.2.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/parallel-3.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/parallel-3.2.2.0
hs-libraries: HSparallel-3.2.2.0-EGl5SOk48TWHAD161C93aQ
depends:
    array-0.5.3.0 base-4.12.0.0 containers-0.6.0.1 deepseq-1.4.4.0
    ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-parallel/html/parallel.haddock
haddock-html: /usr/share/doc/haskell-parallel/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
